===========
cardinality
===========

``cardinality`` is a Python library to determine and check the size of any
iterable.

* Documentation: https://cardinality.readthedocs.org/

* Python Package Index (PyPI): https://pypi.python.org/pypi/cardinality/

* Source code and issue tracker: https://github.com/wbolster/cardinality
